Learn R Programming

gtx (version 0.0.3)

grs.filter.Qrs: Filter SNPs for inclusion in genetic risk score using heterogeneity test.

Description

Performs a stepwise downward "model selection" in which SNPs are iteratively removed from the risk score until the heterogeneity test is no longer significant at the specified threshold.

Usage

grs.filter.Qrs(w, b, s, p.thresh = 0.05)

Arguments

w
coefficients for the risk score
b
aligned beta coefficients in the testing dataset
s
standard errors
p.thresh
P-value threshold

Details

This function needs better documentation!